Examples
=========

Templates
-----------

  * [Objects First](https://codeberg.org/a_siebel/miniworldmaker/src/branch/main/examples/objects_first)

  * [Classes First](https://codeberg.org/a_siebel/miniworldmaker/src/branch/main/examples/classes_first)


Snippets
----------

These examples are used as tests. They show how different concepts are realized in miniworldmaker:

  * [Basics and Costumes](https://codeberg.org/a_siebel/miniworldmaker/src/branch/main/examples/tests/1%20Costumes%20and%20Backgrounds)

  * [Moving](https://codeberg.org/a_siebel/miniworldmaker/src/branch/main/examples/tests/2%20Movement)

  * [Animations](https://codeberg.org/a_siebel/miniworldmaker/src/branch/main/examples/tests/3%20Animations)

  * [Physics](https://codeberg.org/a_siebel/miniworldmaker/src/branch/main/examples/tests/4%20Physics)

  * [Timer](https://codeberg.org/a_siebel/miniworldmaker/src/branch/main/examples/tests/5%20Timer)

  * [GUI](https://codeberg.org/a_siebel/miniworldmaker/src/branch/main/examples/tests/6%20GUI)

  * [Processing](https://codeberg.org/a_siebel/miniworldmaker/src/branch/main/examples/tests/7%20Processing)

  * [Events](https://codeberg.org/a_siebel/miniworldmaker/src/branch/main/examples/tests/8%20Events)